#################
tsam's Change Log
#################

In tsam's latest release (1.1.0) the following functionalities were included:

* Segmentation - the clustering of adjacent time steps - according to `Pineda et al. (2018) <https://ieeexplore.ieee.org/abstract/document/8369128>`_
* k-MILP - an extension of the MILP-based k-medoids clustering that allows automatic identification of extreme periods according to `Zatti et al. (2019) <https://www.sciencedirect.com/science/article/abs/pii/S0360544219309077>`_
* The option to dynamically choose whether to clusters found should be represented by their centroid or medoid.